//+------------------------------------------------------------------+
//|                                                          TOP.mq4 |
//+------------------------------------------------------------------+
//
// <Entry>
// Order when 2SMMA crosses with daily open pivot
// When SMMA goes bellow to above daily open, buy at new bar open.
// When SMMA goes above to bellow daily open, sell at new bar open.
//
// <S/L> <T/P>
// No S/L & T/P
//
// <TF>
// H1
//
// <Used indicator>
// "PVD$FL_v1"                    // v0.92
//
// <History>
// v0.9 2007-Nov-30th by hiro23
// Draft coded
//
// v0.91 2007-Dec-1st by hiro23
// bug fixed
//
// v0.92 2007-Dec-2nd by hiro23
// change indicator to use GMT shift
// "PrevDayAndFloatingPivot_O" -> "PVD$FL_v1"

#property link "http://www.forex-tsd.com/suggestions-trading-systems/8519-only-pivot.html"

extern int GmtShift = 0;      // v0.92
extern int MA_Period = 2;
extern int MA_Method = MODE_SMMA;

int Bar;                      // For Checking Re-Entry 
int MagicNum = 897348798;
//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
  {
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator deinitialization function                       |
//+------------------------------------------------------------------+
int deinit()
  {
   return(0);
  }
//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start() {
   double MA2BarsEarlier, Pivot2BarsEarlier, MAprevious, Pivotprevious;
   double PosVol = 0.1; // Position size (fixed)
   
   if (Bar != Bars) {   
      // Moving Average calculation
      MAprevious = iMA(NULL, 0, MA_Period, 0, MA_Method, PRICE_WEIGHTED, 1);     // Value of 1 bar earlier
      MA2BarsEarlier = iMA(NULL, 0, MA_Period, 0, MA_Method, PRICE_WEIGHTED, 2); // Value of 2 bar earlier

      // Open Pivot calculation
      Pivotprevious = iCustom(NULL, 0, "PVD$FL_v1", GmtShift, MA_Period, MA_Method, PRICE_WEIGHTED, 0, 1);       // Value of 1 bar earlier // v0.92
      Pivot2BarsEarlier = iCustom(NULL, 0, "PVD$FL_v1", GmtShift, MA_Period, MA_Method, PRICE_WEIGHTED, 0, 2);   // Value of 2 bar earlier // v0.92
      
      // If Up signal, buy
      if ((MAprevious > Pivotprevious) && (MA2BarsEarlier < Pivot2BarsEarlier)) {
         CloseOpenPos();
         OrderSend(Symbol(), OP_BUY, PosVol, Ask, 3, 0, 0, "Buy", MagicNum, 0, Blue);
      // If Down signal, sell
      } else if ((MAprevious < Pivotprevious) && (MA2BarsEarlier > Pivot2BarsEarlier)) {
         CloseOpenPos();
         OrderSend(Symbol(), OP_SELL, PosVol, Bid, 3, 0, 0, "Sell", MagicNum, 0, Red);
      }
      
      Bar = Bars;
   }
   return(0);
}

int CloseOpenPos() {
   int total = OrdersTotal();
   for (int i = total - 1; i >= 0; i--) {
      OrderSelect(i, SELECT_BY_POS);
      // Skip if this is other system's order.
      if (OrderMagicNumber() != MagicNum) {
//         break;  // v0.91 bug fix
         continue; // v0.91 bug fix
      }
      int type    = OrderType();
      bool result = false;
    
      switch (type) {
         //Close opened long positions
         case OP_BUY:
            result = OrderClose( OrderTicket(), OrderLots(), MarketInfo(OrderSymbol(), MODE_BID), 5, Red );
            break;
         //Close opened short positions
         case OP_SELL:
            result = OrderClose( OrderTicket(), OrderLots(), MarketInfo(OrderSymbol(), MODE_ASK), 5, Red );
            break;                 
      }
      if(result == false) {
         Alert("Order " , OrderTicket() , " failed to close. Error:" , GetLastError() );
         Sleep(3000);
      }  
   }
   return(0);     // v0.91 bug fix
}